//
//  io_RGB.cpp
//  xcodeJL
//
//  Created by José Luis Lisani Roca on 27/01/12.
//  Copyright (c) 2012 Universitat Illes Balears. All rights reserved.
//

#include <stdlib.h>

/**
 * \brief Convert color data from 1 array with format 
 * RR...RRGG...GGBB...BB to 3 arrays with formats RRR..., GGG..., BBB... 
 *
 *
 * @param[in] input input array
 * @param[out] RR, GG, BB output arrays 
 * @param[in] size number of colors
 *
 */
void input2RGB(unsigned char *input, 
               unsigned char **RR, unsigned char **GG, unsigned char **BB, 
               int size)
{
    unsigned char *R, *G, *B;
    int n;
    
    R=new unsigned char[size];
    G=new unsigned char[size];
    B=new unsigned char[size];
    for (n=0; n < size; n++) {
        R[n]=input[n];
        G[n]=input[size+n];
        B[n]=input[2*size+n];
    }
    
    *RR=R;
    *GG=G;
    *BB=B;
}

/**
 * \brief Convert color data from 3 arrays with formats 
 * RRR..., GGG..., BBB...  to 1 array with format RR...RRGG...GGBB...BB 
 *
 *
 * @param[in] R, G, B input arrays 
 * @param[out] output input array
 * @oaram[in] size number of colors
 *
 */
void RGB2output(unsigned char *R, unsigned char *G, unsigned char *B, 
                unsigned char *output, int size)
{
    int n;
    
    for (n=0; n < size; n++) {
        output[n]=R[n];
        output[size+n]=G[n];
        output[2*size+n]=B[n];
    }
}

unsigned char *RGBtoI(unsigned char *R, unsigned char *G, unsigned char *B, 
                        int size)
{
    unsigned char *I=new unsigned char[size];
    for (int n=0; n < size; n++) 
        I[n]=(unsigned char) (0.5f + ((float) R[n] + (float) G[n] + (float) B[n])/3.0f);
    
    return I;
}

