/**
 * 
 * Copyright (c) 2020, Jose-Luis Lisani, joseluis.lisani@uib.es
 * All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


#include <math.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <vector>
#include <algorithm>
using namespace std;

#include "io_png.h"
#include "io_RGB.h"


//Conversion formulas from RGB to HSI color space,
//as defined in article "Automatic Color Palette"
//http://dx.doi.org/10.3934/ipi.2007.1.265
//and Ph.D. Thesis "Analytical methods for the study of color in digital images"
//Ana Belén Petro Balaguer, 2006
//https://dspace.uib.es/xmlui/handle/10803/9409


//H: angle between 0 and 360 degrees
//S: value between 0 and 208.20662813657015 (e.g. for RGB=(255, 0, 0))
//I: value between 0 and 255
void colorRGBtonewHSI(float R, float G, float B, float &H, float &S, float &I)
{
  double PI=3.14159265358979323846;

  I=(R+G+B)/3;
  S=sqrt( (R-I)*(R-I) + (G-I)*(G-I) + (B-I)*(B-I) );
  double cosH;
  H=0;
  if (S == 0) return; 
  cosH=(G-B)/(sqrt(2.0f)*S);
  if (fabs(cosH) > 1) cosH/=fabs(cosH);
  H=(float) acos(cosH); 
  H*=(float) (180/PI);
  //assign sign to the angle
  float proj2; //projection onto vector (-2, 1, 1)
  proj2=-2*(R-I)+(G-I)+(B-I);
  if (proj2 < 0) H=-H;
  if (H < 0) H+=360;
  if (H == 360) H=0;
    
} 






